@@ -1,4 +1,4 @@
-/* A Bison parser, made by GNU Bison 3.3.2.  */
+/* A Bison parser, made by GNU Bison 3.4.1.  */
 
 /* Bison implementation for Yacc-like parsers in C
 
@@ -48,7 +48,7 @@
 #define YYBISON 1
 
 /* Bison version.  */
-#define YYBISON_VERSION "3.3.2"
+#define YYBISON_VERSION "3.4.1"
 
 /* Skeleton name.  */
 #define YYSKELETON_NAME "yacc.c"
@@ -66,7 +66,7 @@
 
 
 /* First part of user prologue.  */
-#line 29 "ginsh_parser.ypp" /* yacc.c:337  */
+#line 29 "ginsh_parser.ypp"
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -154,7 +154,8 @@ static void insert_fcn_help(const char *name, const char *str);
 static void print_help(const string &topic);
 static void print_help_topics(void);
 
-#line 158 "ginsh_parser.cpp" /* yacc.c:337  */
+#line 158 "ginsh_parser.cpp"
+
 # ifndef YY_NULLPTR
 #  if defined __cplusplus
 #   if 201103L <= __cplusplus
@@ -175,8 +176,8 @@ static void print_help_topics(void);
 # define YYERROR_VERBOSE 0
 #endif
 
-/* In a future release of Bison, this section will be replaced
-   by #include "ginsh_parser.hpp".  */
+/* Use api.header.include to #include this header
+   instead of duplicating it here.  */
 #ifndef YY_YY_GINSH_PARSER_HPP_INCLUDED
 # define YY_YY_GINSH_PARSER_HPP_INCLUDED
 /* Debug traces.  */
@@ -362,6 +363,8 @@ typedef short yytype_int16;
 #endif
 
 
+#define YY_ASSERT(E) ((void) (0 && (E)))
+
 #if ! defined yyoverflow || YYERROR_VERBOSE
 
 /* The parser invokes alloca or malloc; define the necessary symbols.  */
@@ -1284,6 +1287,8 @@ yynewstate:
 | yynewstate -- set current state (the top of the stack) to yystate.  |
 `--------------------------------------------------------------------*/
 yysetstate:
+  YYDPRINTF ((stderr, "Entering state %d\n", yystate));
+  YY_ASSERT (0 <= yystate && yystate < YYNSTATES);
   *yyssp = (yytype_int16) yystate;
 
   if (yyss + yystacksize - 1 <= yyssp)
@@ -1346,8 +1351,6 @@ yysetstate:
     }
 #endif /* !defined yyoverflow && !defined YYSTACK_RELOCATE */
 
-  YYDPRINTF ((stderr, "Entering state %d\n", yystate));
-
   if (yystate == YYFINAL)
     YYACCEPT;
 
@@ -1415,7 +1418,6 @@ yybackup:
   YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
   *++yyvsp = yylval;
   YY_IGNORE_MAYBE_UNINITIALIZED_END
-
   goto yynewstate;
 
 
@@ -1450,8 +1452,8 @@ yyreduce:
   YY_REDUCE_PRINT (yyn);
   switch (yyn)
     {
-        case 5:
-#line 148 "ginsh_parser.ypp" /* yacc.c:1652  */
+  case 5:
+#line 148 "ginsh_parser.ypp"
     {
 		try {
 			cout << yyvsp[-1] << endl;
@@ -1461,11 +1463,11 @@ yyreduce:
 			YYERROR;
 		}
 	}
-#line 1465 "ginsh_parser.cpp" /* yacc.c:1652  */
+#line 1467 "ginsh_parser.cpp"
     break;
 
   case 6:
-#line 157 "ginsh_parser.ypp" /* yacc.c:1652  */
+#line 157 "ginsh_parser.ypp"
     {
 		try {
 			push(yyvsp[-1]);
@@ -1474,11 +1476,11 @@ yyreduce:
 			YYERROR;
 		}
 	}
-#line 1478 "ginsh_parser.cpp" /* yacc.c:1652  */
+#line 1480 "ginsh_parser.cpp"
     break;
 
   case 7:
-#line 165 "ginsh_parser.ypp" /* yacc.c:1652  */
+#line 165 "ginsh_parser.ypp"
     {
 		try {
 			yyvsp[-2].print(print_tree(std::cout));
@@ -1487,11 +1489,11 @@ yyreduce:
 			YYERROR;
 		}
 	}
-#line 1491 "ginsh_parser.cpp" /* yacc.c:1652  */
+#line 1493 "ginsh_parser.cpp"
     break;
 
   case 8:
-#line 173 "ginsh_parser.ypp" /* yacc.c:1652  */
+#line 173 "ginsh_parser.ypp"
     {
 		try {
 			ex e = yyvsp[-2];
@@ -1506,11 +1508,11 @@ yyreduce:
 			YYERROR;
 		}
 	}
-#line 1510 "ginsh_parser.cpp" /* yacc.c:1652  */
+#line 1512 "ginsh_parser.cpp"
     break;
 
   case 9:
-#line 187 "ginsh_parser.ypp" /* yacc.c:1652  */
+#line 187 "ginsh_parser.ypp"
     {
 		try {
 			yyvsp[-2].print(print_latex(std::cout)); cout << endl;
@@ -1519,11 +1521,11 @@ yyreduce:
 			YYERROR;
 		}
 	}
-#line 1523 "ginsh_parser.cpp" /* yacc.c:1652  */
+#line 1525 "ginsh_parser.cpp"
     break;
 
   case 10:
-#line 195 "ginsh_parser.ypp" /* yacc.c:1652  */
+#line 195 "ginsh_parser.ypp"
     {
 		try {
 			yyvsp[-2].print(print_csrc_double(std::cout)); cout << endl;
@@ -1532,59 +1534,59 @@ yyreduce:
 			YYERROR;
 		}
 	}
-#line 1536 "ginsh_parser.cpp" /* yacc.c:1652  */
+#line 1538 "ginsh_parser.cpp"
     break;
 
   case 11:
-#line 203 "ginsh_parser.ypp" /* yacc.c:1652  */
+#line 203 "ginsh_parser.ypp"
     {print_help(ex_to<symbol>(yyvsp[0]).get_name());}
-#line 1542 "ginsh_parser.cpp" /* yacc.c:1652  */
+#line 1544 "ginsh_parser.cpp"
     break;
 
   case 12:
-#line 204 "ginsh_parser.ypp" /* yacc.c:1652  */
+#line 204 "ginsh_parser.ypp"
     {print_help("time");}
-#line 1548 "ginsh_parser.cpp" /* yacc.c:1652  */
+#line 1550 "ginsh_parser.cpp"
     break;
 
   case 13:
-#line 205 "ginsh_parser.ypp" /* yacc.c:1652  */
+#line 205 "ginsh_parser.ypp"
     {print_help("print");}
-#line 1554 "ginsh_parser.cpp" /* yacc.c:1652  */
+#line 1556 "ginsh_parser.cpp"
     break;
 
   case 14:
-#line 206 "ginsh_parser.ypp" /* yacc.c:1652  */
+#line 206 "ginsh_parser.ypp"
     {print_help("iprint");}
-#line 1560 "ginsh_parser.cpp" /* yacc.c:1652  */
+#line 1562 "ginsh_parser.cpp"
     break;
 
   case 15:
-#line 207 "ginsh_parser.ypp" /* yacc.c:1652  */
+#line 207 "ginsh_parser.ypp"
     {print_help("print_latex");}
-#line 1566 "ginsh_parser.cpp" /* yacc.c:1652  */
+#line 1568 "ginsh_parser.cpp"
     break;
 
   case 16:
-#line 208 "ginsh_parser.ypp" /* yacc.c:1652  */
+#line 208 "ginsh_parser.ypp"
     {print_help("print_csrc");}
-#line 1572 "ginsh_parser.cpp" /* yacc.c:1652  */
+#line 1574 "ginsh_parser.cpp"
     break;
 
   case 17:
-#line 209 "ginsh_parser.ypp" /* yacc.c:1652  */
+#line 209 "ginsh_parser.ypp"
     {print_help_topics();}
-#line 1578 "ginsh_parser.cpp" /* yacc.c:1652  */
+#line 1580 "ginsh_parser.cpp"
     break;
 
   case 18:
-#line 210 "ginsh_parser.ypp" /* yacc.c:1652  */
+#line 210 "ginsh_parser.ypp"
     {YYACCEPT;}
-#line 1584 "ginsh_parser.cpp" /* yacc.c:1652  */
+#line 1586 "ginsh_parser.cpp"
     break;
 
   case 19:
-#line 211 "ginsh_parser.ypp" /* yacc.c:1652  */
+#line 211 "ginsh_parser.ypp"
     {
 		cout << "This program is free software; you can redistribute it and/or modify it under\n";
 		cout << "the terms of the GNU General Public License as published by the Free Software\n";
@@ -1598,81 +1600,81 @@ yyreduce:
 		cout << "this program. If not, write to the Free Software Foundation,\n";
 		cout << "51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.\n";
 	}
-#line 1602 "ginsh_parser.cpp" /* yacc.c:1652  */
+#line 1604 "ginsh_parser.cpp"
     break;
 
   case 20:
-#line 224 "ginsh_parser.ypp" /* yacc.c:1652  */
+#line 224 "ginsh_parser.ypp"
     {cout << "Nothing happens.\n";}
-#line 1608 "ginsh_parser.cpp" /* yacc.c:1652  */
+#line 1610 "ginsh_parser.cpp"
     break;
 
   case 21:
-#line 225 "ginsh_parser.ypp" /* yacc.c:1652  */
+#line 225 "ginsh_parser.ypp"
     {cout << "You're not carrying anything.\n";}
-#line 1614 "ginsh_parser.cpp" /* yacc.c:1652  */
+#line 1616 "ginsh_parser.cpp"
     break;
 
   case 22:
-#line 226 "ginsh_parser.ypp" /* yacc.c:1652  */
+#line 226 "ginsh_parser.ypp"
     {cout << "You're in a twisty little maze of passages, all alike.\n";}
-#line 1620 "ginsh_parser.cpp" /* yacc.c:1652  */
+#line 1622 "ginsh_parser.cpp"
     break;
 
   case 23:
-#line 227 "ginsh_parser.ypp" /* yacc.c:1652  */
+#line 227 "ginsh_parser.ypp"
     {
 		cout << "If you were to quit now, you would score ";
 		cout << (syms.size() > 350 ? 350 : syms.size());
 		cout << " out of a possible 350.\n";
 	}
-#line 1630 "ginsh_parser.cpp" /* yacc.c:1652  */
+#line 1632 "ginsh_parser.cpp"
     break;
 
   case 24:
-#line 232 "ginsh_parser.ypp" /* yacc.c:1652  */
+#line 232 "ginsh_parser.ypp"
     { symboltype = domain::real; }
-#line 1636 "ginsh_parser.cpp" /* yacc.c:1652  */
+#line 1638 "ginsh_parser.cpp"
     break;
 
   case 25:
-#line 233 "ginsh_parser.ypp" /* yacc.c:1652  */
+#line 233 "ginsh_parser.ypp"
     { symboltype = domain::complex; }
-#line 1642 "ginsh_parser.cpp" /* yacc.c:1652  */
+#line 1644 "ginsh_parser.cpp"
     break;
 
   case 26:
-#line 234 "ginsh_parser.ypp" /* yacc.c:1652  */
+#line 234 "ginsh_parser.ypp"
     { START_TIMER }
-#line 1648 "ginsh_parser.cpp" /* yacc.c:1652  */
+#line 1650 "ginsh_parser.cpp"
     break;
 
   case 27:
-#line 234 "ginsh_parser.ypp" /* yacc.c:1652  */
+#line 234 "ginsh_parser.ypp"
     { STOP_TIMER PRINT_TIME_USED }
-#line 1654 "ginsh_parser.cpp" /* yacc.c:1652  */
+#line 1656 "ginsh_parser.cpp"
     break;
 
   case 28:
-#line 235 "ginsh_parser.ypp" /* yacc.c:1652  */
+#line 235 "ginsh_parser.ypp"
     {yyclearin; yyerrok;}
-#line 1660 "ginsh_parser.cpp" /* yacc.c:1652  */
+#line 1662 "ginsh_parser.cpp"
     break;
 
   case 29:
-#line 236 "ginsh_parser.ypp" /* yacc.c:1652  */
+#line 236 "ginsh_parser.ypp"
     {yyclearin; yyerrok;}
-#line 1666 "ginsh_parser.cpp" /* yacc.c:1652  */
+#line 1668 "ginsh_parser.cpp"
     break;
 
   case 30:
-#line 239 "ginsh_parser.ypp" /* yacc.c:1652  */
+#line 239 "ginsh_parser.ypp"
     {yyval = yyvsp[0];}
-#line 1672 "ginsh_parser.cpp" /* yacc.c:1652  */
+#line 1674 "ginsh_parser.cpp"
     break;
 
   case 31:
-#line 240 "ginsh_parser.ypp" /* yacc.c:1652  */
+#line 240 "ginsh_parser.ypp"
     {
 		auto i = assigned_symbol_table.find(yyvsp[0]);
 		if (i == assigned_symbol_table.end())
@@ -1680,47 +1682,47 @@ yyreduce:
 		else
 			yyval = i->second;
 	}
-#line 1684 "ginsh_parser.cpp" /* yacc.c:1652  */
+#line 1686 "ginsh_parser.cpp"
     break;
 
   case 32:
-#line 247 "ginsh_parser.ypp" /* yacc.c:1652  */
+#line 247 "ginsh_parser.ypp"
     {yyval = yyvsp[-1];}
-#line 1690 "ginsh_parser.cpp" /* yacc.c:1652  */
+#line 1692 "ginsh_parser.cpp"
     break;
 
   case 33:
-#line 248 "ginsh_parser.ypp" /* yacc.c:1652  */
+#line 248 "ginsh_parser.ypp"
     {yyval = yyvsp[0];}
-#line 1696 "ginsh_parser.cpp" /* yacc.c:1652  */
+#line 1698 "ginsh_parser.cpp"
     break;
 
   case 34:
-#line 249 "ginsh_parser.ypp" /* yacc.c:1652  */
+#line 249 "ginsh_parser.ypp"
     {yyval = yyvsp[0];}
-#line 1702 "ginsh_parser.cpp" /* yacc.c:1652  */
+#line 1704 "ginsh_parser.cpp"
     break;
 
   case 35:
-#line 250 "ginsh_parser.ypp" /* yacc.c:1652  */
+#line 250 "ginsh_parser.ypp"
     {yyval = exstack[0];}
-#line 1708 "ginsh_parser.cpp" /* yacc.c:1652  */
+#line 1710 "ginsh_parser.cpp"
     break;
 
   case 36:
-#line 251 "ginsh_parser.ypp" /* yacc.c:1652  */
+#line 251 "ginsh_parser.ypp"
     {yyval = exstack[1];}
-#line 1714 "ginsh_parser.cpp" /* yacc.c:1652  */
+#line 1716 "ginsh_parser.cpp"
     break;
 
   case 37:
-#line 252 "ginsh_parser.ypp" /* yacc.c:1652  */
+#line 252 "ginsh_parser.ypp"
     {yyval = exstack[2];}
-#line 1720 "ginsh_parser.cpp" /* yacc.c:1652  */
+#line 1722 "ginsh_parser.cpp"
     break;
 
   case 38:
-#line 253 "ginsh_parser.ypp" /* yacc.c:1652  */
+#line 253 "ginsh_parser.ypp"
     {
 		auto i = find_function(yyvsp[-3], yyvsp[-1].nops());
 		if (i->second.is_ginac) {
@@ -1729,185 +1731,186 @@ yyreduce:
 			yyval = (i->second.p)(ex_to<exprseq>(yyvsp[-1]));
 		}
 	}
-#line 1733 "ginsh_parser.cpp" /* yacc.c:1652  */
+#line 1735 "ginsh_parser.cpp"
     break;
 
   case 39:
-#line 261 "ginsh_parser.ypp" /* yacc.c:1652  */
+#line 261 "ginsh_parser.ypp"
     {yyval = yyvsp[0]; Digits = ex_to<numeric>(yyvsp[0]).to_int();}
-#line 1739 "ginsh_parser.cpp" /* yacc.c:1652  */
+#line 1741 "ginsh_parser.cpp"
     break;
 
   case 40:
-#line 262 "ginsh_parser.ypp" /* yacc.c:1652  */
+#line 262 "ginsh_parser.ypp"
     {yyval = yyvsp[0]; assigned_symbol_table[yyvsp[-2]] = yyvsp[0]; }
-#line 1745 "ginsh_parser.cpp" /* yacc.c:1652  */
+#line 1747 "ginsh_parser.cpp"
     break;
 
   case 41:
-#line 263 "ginsh_parser.ypp" /* yacc.c:1652  */
+#line 263 "ginsh_parser.ypp"
     {yyval = yyvsp[-2] == yyvsp[0];}
-#line 1751 "ginsh_parser.cpp" /* yacc.c:1652  */
+#line 1753 "ginsh_parser.cpp"
     break;
 
   case 42:
-#line 264 "ginsh_parser.ypp" /* yacc.c:1652  */
+#line 264 "ginsh_parser.ypp"
     {yyval = yyvsp[-2] != yyvsp[0];}
-#line 1757 "ginsh_parser.cpp" /* yacc.c:1652  */
+#line 1759 "ginsh_parser.cpp"
     break;
 
   case 43:
-#line 265 "ginsh_parser.ypp" /* yacc.c:1652  */
+#line 265 "ginsh_parser.ypp"
     {yyval = yyvsp[-2] < yyvsp[0];}
-#line 1763 "ginsh_parser.cpp" /* yacc.c:1652  */
+#line 1765 "ginsh_parser.cpp"
     break;
 
   case 44:
-#line 266 "ginsh_parser.ypp" /* yacc.c:1652  */
+#line 266 "ginsh_parser.ypp"
     {yyval = yyvsp[-2] <= yyvsp[0];}
-#line 1769 "ginsh_parser.cpp" /* yacc.c:1652  */
+#line 1771 "ginsh_parser.cpp"
     break;
 
   case 45:
-#line 267 "ginsh_parser.ypp" /* yacc.c:1652  */
+#line 267 "ginsh_parser.ypp"
     {yyval = yyvsp[-2] > yyvsp[0];}
-#line 1775 "ginsh_parser.cpp" /* yacc.c:1652  */
+#line 1777 "ginsh_parser.cpp"
     break;
 
   case 46:
-#line 268 "ginsh_parser.ypp" /* yacc.c:1652  */
+#line 268 "ginsh_parser.ypp"
     {yyval = yyvsp[-2] >= yyvsp[0];}
-#line 1781 "ginsh_parser.cpp" /* yacc.c:1652  */
+#line 1783 "ginsh_parser.cpp"
     break;
 
   case 47:
-#line 269 "ginsh_parser.ypp" /* yacc.c:1652  */
+#line 269 "ginsh_parser.ypp"
     {yyval = yyvsp[-2] + yyvsp[0];}
-#line 1787 "ginsh_parser.cpp" /* yacc.c:1652  */
+#line 1789 "ginsh_parser.cpp"
     break;
 
   case 48:
-#line 270 "ginsh_parser.ypp" /* yacc.c:1652  */
+#line 270 "ginsh_parser.ypp"
     {yyval = yyvsp[-2] - yyvsp[0];}
-#line 1793 "ginsh_parser.cpp" /* yacc.c:1652  */
+#line 1795 "ginsh_parser.cpp"
     break;
 
   case 49:
-#line 271 "ginsh_parser.ypp" /* yacc.c:1652  */
+#line 271 "ginsh_parser.ypp"
     {yyval = yyvsp[-2] * yyvsp[0];}
-#line 1799 "ginsh_parser.cpp" /* yacc.c:1652  */
+#line 1801 "ginsh_parser.cpp"
     break;
 
   case 50:
-#line 272 "ginsh_parser.ypp" /* yacc.c:1652  */
+#line 272 "ginsh_parser.ypp"
     {yyval = yyvsp[-2] / yyvsp[0];}
-#line 1805 "ginsh_parser.cpp" /* yacc.c:1652  */
+#line 1807 "ginsh_parser.cpp"
     break;
 
   case 51:
-#line 273 "ginsh_parser.ypp" /* yacc.c:1652  */
+#line 273 "ginsh_parser.ypp"
     {yyval = -yyvsp[0];}
-#line 1811 "ginsh_parser.cpp" /* yacc.c:1652  */
+#line 1813 "ginsh_parser.cpp"
     break;
 
   case 52:
-#line 274 "ginsh_parser.ypp" /* yacc.c:1652  */
+#line 274 "ginsh_parser.ypp"
     {yyval = yyvsp[0];}
-#line 1817 "ginsh_parser.cpp" /* yacc.c:1652  */
+#line 1819 "ginsh_parser.cpp"
     break;
 
   case 53:
-#line 275 "ginsh_parser.ypp" /* yacc.c:1652  */
+#line 275 "ginsh_parser.ypp"
     {yyval = power(yyvsp[-2], yyvsp[0]);}
-#line 1823 "ginsh_parser.cpp" /* yacc.c:1652  */
+#line 1825 "ginsh_parser.cpp"
     break;
 
   case 54:
-#line 276 "ginsh_parser.ypp" /* yacc.c:1652  */
+#line 276 "ginsh_parser.ypp"
     {yyval = factorial(yyvsp[-1]);}
-#line 1829 "ginsh_parser.cpp" /* yacc.c:1652  */
+#line 1831 "ginsh_parser.cpp"
     break;
 
   case 55:
-#line 277 "ginsh_parser.ypp" /* yacc.c:1652  */
+#line 277 "ginsh_parser.ypp"
     {yyval = yyvsp[-1];}
-#line 1835 "ginsh_parser.cpp" /* yacc.c:1652  */
+#line 1837 "ginsh_parser.cpp"
     break;
 
   case 56:
-#line 278 "ginsh_parser.ypp" /* yacc.c:1652  */
+#line 278 "ginsh_parser.ypp"
     {yyval = yyvsp[-1];}
-#line 1841 "ginsh_parser.cpp" /* yacc.c:1652  */
+#line 1843 "ginsh_parser.cpp"
     break;
 
   case 57:
-#line 279 "ginsh_parser.ypp" /* yacc.c:1652  */
+#line 279 "ginsh_parser.ypp"
     {yyval = lst_to_matrix(ex_to<lst>(yyvsp[-1]));}
-#line 1847 "ginsh_parser.cpp" /* yacc.c:1652  */
+#line 1849 "ginsh_parser.cpp"
     break;
 
   case 58:
-#line 282 "ginsh_parser.ypp" /* yacc.c:1652  */
+#line 282 "ginsh_parser.ypp"
     {yyval = exprseq{yyvsp[0]};}
-#line 1853 "ginsh_parser.cpp" /* yacc.c:1652  */
+#line 1855 "ginsh_parser.cpp"
     break;
 
   case 59:
-#line 283 "ginsh_parser.ypp" /* yacc.c:1652  */
+#line 283 "ginsh_parser.ypp"
     {exprseq es(ex_to<exprseq>(yyvsp[-2])); yyval = es.append(yyvsp[0]);}
-#line 1859 "ginsh_parser.cpp" /* yacc.c:1652  */
+#line 1861 "ginsh_parser.cpp"
     break;
 
   case 60:
-#line 286 "ginsh_parser.ypp" /* yacc.c:1652  */
+#line 286 "ginsh_parser.ypp"
     {yyval = *new lst;}
-#line 1865 "ginsh_parser.cpp" /* yacc.c:1652  */
+#line 1867 "ginsh_parser.cpp"
     break;
 
   case 61:
-#line 287 "ginsh_parser.ypp" /* yacc.c:1652  */
+#line 287 "ginsh_parser.ypp"
     {yyval = yyvsp[0];}
-#line 1871 "ginsh_parser.cpp" /* yacc.c:1652  */
+#line 1873 "ginsh_parser.cpp"
     break;
 
   case 62:
-#line 290 "ginsh_parser.ypp" /* yacc.c:1652  */
+#line 290 "ginsh_parser.ypp"
     {yyval = lst{yyvsp[0]};}
-#line 1877 "ginsh_parser.cpp" /* yacc.c:1652  */
+#line 1879 "ginsh_parser.cpp"
     break;
 
   case 63:
-#line 291 "ginsh_parser.ypp" /* yacc.c:1652  */
+#line 291 "ginsh_parser.ypp"
     {lst l(ex_to<lst>(yyvsp[-2])); yyval = l.append(yyvsp[0]);}
-#line 1883 "ginsh_parser.cpp" /* yacc.c:1652  */
+#line 1885 "ginsh_parser.cpp"
     break;
 
   case 64:
-#line 294 "ginsh_parser.ypp" /* yacc.c:1652  */
+#line 294 "ginsh_parser.ypp"
     {yyval = lst{yyvsp[-1]};}
-#line 1889 "ginsh_parser.cpp" /* yacc.c:1652  */
+#line 1891 "ginsh_parser.cpp"
     break;
 
   case 65:
-#line 295 "ginsh_parser.ypp" /* yacc.c:1652  */
+#line 295 "ginsh_parser.ypp"
     {lst l(ex_to<lst>(yyvsp[-4])); yyval = l.append(yyvsp[-1]);}
-#line 1895 "ginsh_parser.cpp" /* yacc.c:1652  */
+#line 1897 "ginsh_parser.cpp"
     break;
 
   case 66:
-#line 298 "ginsh_parser.ypp" /* yacc.c:1652  */
+#line 298 "ginsh_parser.ypp"
     {yyval = lst{yyvsp[0]};}
-#line 1901 "ginsh_parser.cpp" /* yacc.c:1652  */
+#line 1903 "ginsh_parser.cpp"
     break;
 
   case 67:
-#line 299 "ginsh_parser.ypp" /* yacc.c:1652  */
+#line 299 "ginsh_parser.ypp"
     {lst l(ex_to<lst>(yyvsp[-2])); yyval = l.append(yyvsp[0]);}
-#line 1907 "ginsh_parser.cpp" /* yacc.c:1652  */
+#line 1909 "ginsh_parser.cpp"
     break;
 
 
-#line 1911 "ginsh_parser.cpp" /* yacc.c:1652  */
+#line 1913 "ginsh_parser.cpp"
+
       default: break;
     }
   /* User semantic actions sometimes alter yychar, and that requires
@@ -2138,7 +2141,7 @@ yyreturn:
 #endif
   return yyresult;
 }
-#line 307 "ginsh_parser.ypp" /* yacc.c:1918  */
+#line 307 "ginsh_parser.ypp"
 
 // Error print routine
 int yyerror(const char *s)
